@@ -6,7 +6,7 @@ Exceções de configuração para OCR
 Define exceções relacionadas à configuração durante OCR.
 """
 
-from .base import OCRError
+from appserver_sdk_python_ai.ocr.exceptions.base import OCRError
 
 
 class OCRConfigurationError(OCRError):
