@@ -6,7 +6,7 @@ Exceções relacionadas ao processamento de imagens para OCR
 Define exceções específicas para processamento de imagens durante OCR.
 """
 
-from .base import OCRError
+from appserver_sdk_python_ai.ocr.exceptions.base import OCRError
 
 
 class OCRImageError(OCRError):
