@@ -6,7 +6,7 @@ Exceções de cache para WebScraping
 Define exceções relacionadas ao sistema de cache durante web scraping.
 """
 
-from .base import WebScrapingError
+from appserver_sdk_python_ai.webscraping.exceptions.base import WebScrapingError
 
 
 class CacheError(WebScrapingError):
